@@ -31,6 +31,27 @@
 
 #include "DiceEdit.h"
 
+class DicesModelPainter : public Lum::StringCellPainter
+{
+public:
+  std::wstring GetCellData() const
+  {
+    Dice dice=dynamic_cast<const DicesModel*>(GetModel())->GetEntry(GetRow());
+
+    std::wstring string;
+
+    for (size_t i=0; i<dice.values.size(); i++) {
+      if (i>0) {
+        string.append(L", ");
+      }
+
+      string.append(L"'"+dice.values[i].value+L"'");
+    }
+
+    return string;
+  }
+};
+
 DiceSetEdit::DiceSetEdit(DiceSet& diceSet)
  : diceSet(diceSet),
    name(new Lum::Model::String(diceSet.name)),
@@ -101,6 +122,7 @@ Lum::Object* DiceSetEdit::GetContent()
   table->GetTableView()->SetAutoHSize(true);
   table->GetTableView()->SetAutoFitColumns(true);
   table->SetModel(dicesModel);
+  table->SetPainter(new DicesModelPainter());
   table->SetHeaderModel(headerModel);
   table->SetSelection(selection);
   table->SetDoubleClickAction(editAction);
@@ -112,7 +134,7 @@ Lum::Object* DiceSetEdit::GetContent()
              ->AddSpace()
              ->Add(Lum::Button::Create(_(L"BTN_UPDATE",L"_Edit"),editAction,true,false))
              ->AddSpace()
-             ->Add(Lum::Button::Create(_(L"BTN_CLONE",L"_Dupplicate"),cloneAction,true,false))
+             ->Add(Lum::Button::Create(_(L"BTN_CLONE",L"_Duplicate"),cloneAction,true,false))
              ->AddSpace()
              ->Add(Lum::Button::Create(_(L"BTN_REMOVE",L"_Remove"),removeAction,true,false)));
 
