@@ -67,8 +67,12 @@ public:
     clearAction(new Lum::Model::Action),
     aboutAction(new Lum::Model::Action)
   {
+    GetWindow()->SetScreenOrientationHint(Lum::OS::Window::screenOrientationBothSupported);
+
     currentSet->Disable();
 
+    setsModel->SetEmptyText(L"(No dice sets defined)");
+
     Observe(currentSet);
 
     Observe(configureAction);
@@ -82,35 +86,61 @@ public:
 
   void PreInit()
   {
-    setsModel->SetEmptyText(L"(No dice sets defined)");
-
     Lum::Def::OneOfMany setChoiceDef(Lum::Def::Desc(L"Dice Set"),
                                      currentSet,
                                      setsModel,
                                      new DiceSetModelPainter());
 
-    Lum::Object         *setChoice;
-    Lum::Panel          *vert;
+    if (Lum::OS::display->IsLandscape()) {
+      Lum::Object *setChoice;
+      Lum::Panel  *vert;
 
-    vert=Lum::VPanel::Create(true,true);
+      vert=Lum::VPanel::Create(true,true);
 
-    setChoice=Lum::Manager::Behaviour::Instance()->GetOneOfManyControl(setChoiceDef);
-    setChoice->SetFlex(true,false);
-    setChoice->SetMinWidth(Lum::Base::Size::stdCharWidth,20);
+      setChoice=Lum::Manager::Behaviour::Instance()->GetOneOfManyControl(setChoiceDef);
+      setChoice->SetFlex(true,false);
+      setChoice->SetMinWidth(Lum::Base::Size::stdCharWidth,20);
 
-    vert->Add(setChoice);
+      vert->Add(setChoice);
 
-    vert->AddSpace();
-    vert->Add(Lum::HPanel::Create(true,true)
-              ->Add(Lum::View::Create(new GameArea(true,true), true,true))
-              ->AddSpace()
-              ->Add(Lum::VPanel::Create(false,true)
-                    ->Add(Lum::Button::Create(L"_Throw",rethrowAction,true,false))
-                    ->AddSpace()
-                    ->Add(Lum::Button::Create(L"_Clear",clearAction,true,false))
-                    ->AddSpace(true)));
+      vert->AddSpace();
+      vert->Add(Lum::HPanel::Create(true,true)
+                ->Add(Lum::View::Create(new GameArea(true,true), true,true))
+                ->AddSpace()
+                ->Add(Lum::VPanel::Create(false,true)
+                      ->Add(Lum::Button::Create(L"_Throw",rethrowAction,true,false))
+                      ->AddSpace()
+                      ->Add(Lum::Button::Create(L"_Clear",clearAction,true,false))
+                      ->AddSpace(true)));
 
-    SetMain(vert);
+      SetMain(vert);
+    }
+    else {
+      Lum::Object *setChoice;
+      Lum::Panel  *horiz;
+      Lum::Panel  *vert;
+
+      vert=Lum::VPanel::Create(true,true);
+
+      setChoice=Lum::Manager::Behaviour::Instance()->GetOneOfManyControl(setChoiceDef);
+      setChoice->SetFlex(true,false);
+      setChoice->SetMinWidth(Lum::Base::Size::stdCharWidth,20);
+      vert->Add(setChoice);
+
+      vert->AddSpace();
+
+      vert->Add(Lum::View::Create(new GameArea(true,true),true,true));
+
+      vert->AddSpace();
+
+      horiz=Lum::HPanel::Create(true,false)
+            ->Add(Lum::Button::Create(L"_Throw",rethrowAction,true,false))
+            ->AddSpace()
+            ->Add(Lum::Button::Create(L"_Clear",clearAction,true,false));
+      vert->Add(horiz);
+
+      SetMain(vert);
+    }
 
     Lum::Def::Menu *menu=Lum::Def::Menu::Create();
 
@@ -139,8 +169,8 @@ public:
 
     std::list<DiceSet>::iterator iter=sets.begin();
 
-    if (*currentSet>0) {
-      std::advance(iter,*currentSet-1);
+    if (currentSet->Get()>0) {
+      std::advance(iter,currentSet->Get()-1);
     }
 
     size_t stays=0;
@@ -163,8 +193,8 @@ public:
 
     std::list<DiceSet>::iterator iter=sets.begin();
 
-    if (*currentSet>0) {
-      std::advance(iter,*currentSet-1);
+    if (currentSet->Get()>0) {
+      std::advance(iter,currentSet->Get()-1);
     }
 
     for (std::list<Dice>::iterator dice=iter->dices.begin();
@@ -192,8 +222,8 @@ public:
 
     std::list<DiceSet>::iterator iter=sets.begin();
 
-    if (*currentSet>0) {
-      std::advance(iter,*currentSet-1);
+    if (currentSet->Get()>0) {
+      std::advance(iter,currentSet->Get()-1);
     }
 
     for (std::list<Dice>::iterator dice=iter->dices.begin();
@@ -285,7 +315,7 @@ public:
     info.SetLicense(L"GNU Public License");
 
     srand(time(NULL));
-    
+
     return Lum::GUIApplication<MainDialog>::Initialize();
   }
 };
